@@ -1,5 +1,6 @@
 # coding=utf-8
 """Tests that perform actions over content unit."""
+import pytest
 from pulp_smash.pulp3.bindings import delete_orphans, monitor_task, PulpTaskError
 
 from pulp_python.tests.functional.utils import (
@@ -12,6 +13,7 @@ from pulp_python.tests.functional.utils import (
 from pulp_python.tests.functional.utils import set_up_module as setUpModule  # noqa:F401
 from tempfile import NamedTemporaryFile
 from urllib.parse import urljoin
+from pypi_simple import PyPISimple
 
 from pulp_smash.utils import http_get
 from pulp_python.tests.functional.constants import (
@@ -146,7 +148,7 @@ class ContentUnitTestCase(TestCaseUsingBindings, TestHelpersMixin):
         """
         1) upload file
         2) upload the same file again
-        3) this should fail/send an error
+        3) this should return first unit
         """
         delete_orphans()
         response = self.do_upload()
@@ -154,12 +156,8 @@ class ContentUnitTestCase(TestCaseUsingBindings, TestHelpersMixin):
         content_unit = self.content_api.read(created_resources[0])
         self.check_package_data(content_unit.to_dict())
 
-        with self.assertRaises(PulpTaskError) as cm:
-            monitor_task(self.do_upload().task)
-        task_report = cm.exception.task.to_dict()
-        msg = "This field must be unique"
-        self.assertTrue("sha256" in task_report["error"]["description"])
-        self.assertTrue(msg in task_report["error"]["description"])
+        created_resources = monitor_task(self.do_upload().task).created_resources
+        self.assertEqual(content_unit.pulp_href, created_resources[0])
 
     def test_08_upload_same_filename_different_artifact(self):
         """
@@ -231,3 +229,16 @@ class ContentUnitTestCase(TestCaseUsingBindings, TestHelpersMixin):
         for k, v in expected.items():
             with self.subTest(key=k):
                 self.assertEqual(content_unit[k], v)
+
+
+@pytest.mark.parallel
+def test_upload_metadata_23_spec(python_content_factory):
+    """Test that packages using metadata spec 2.3 can be uploaded to pulp."""
+    filename = "urllib3-2.2.2-py3-none-any.whl"
+    with PyPISimple() as client:
+        page = client.get_project_page("urllib3")
+        for package in page.packages:
+            if package.filename == filename:
+                content = python_content_factory(filename, url=package.url)
+                assert content.metadata_version == "2.3"
+                break
